@@ -1,9 +1,7 @@
 package infra
 
 import (
-	"github.com/v2fly/v2ray-core/v4/common/strmatcher"
-	"regexp"
-	"strings"
+	"github.com/v2fly/v2ray-core/v5/common/strmatcher"
 	"sync/atomic"
 )
 
@@ -19,7 +17,7 @@ func (g *DomainMatcherGroup) Match(dm string) bool {
 
 func (g *DomainMatcherGroup) Add(dm string) {
 	atomic.AddUint32(&g.id, 1)
-	g.g.Add(dm, g.id)
+	g.g.AddDomainMatcher(strmatcher.DomainMatcher(dm), g.id)
 }
 
 type FullMatcherGroup struct {
@@ -34,25 +32,5 @@ func (g *FullMatcherGroup) Match(dm string) bool {
 
 func (g *FullMatcherGroup) Add(dm string) {
 	atomic.AddUint32(&g.id, 1)
-	g.g.Add(dm, g.id)
-}
-
-type RegexMatcher struct {
-	Pattern *regexp.Regexp
-}
-
-func (m *RegexMatcher) Match(s string) bool {
-	return m.Pattern.MatchString(s)
-}
-func (m *RegexMatcher) String() string {
-	return "regexp:" + m.Pattern.String()
-}
-
-type SubstrMatcher string
-
-func (m SubstrMatcher) Match(s string) bool {
-	return strings.Contains(s, string(m))
-}
-func (m SubstrMatcher) String() string {
-	return "contains:" + string(m)
+	g.g.AddFullMatcher(strmatcher.FullMatcher(dm), g.id)
 }
